#
# spec file for package libetpan
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 20
Name:           libetpan
Version:        1.9.4
Release:        bp154.1.29
Summary:        Mail Handling Library
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://www.etpan.org/libetpan.html
Source0:        https://github.com/dinhviethoa/libetpan/archive/%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  cyrus-sasl-devel
BuildRequires:  db-devel
# Stupid dependency. Compiles with gcc but tries to link with g++.
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  openssl-devel

%description
libEtPan is a mail purpose library. It will be used for low-level mail
handling: network protocols (IMAP/NNTP/POP3/SMTP over TCP/IP and
SSL/TCP/IP, already implemented), local storage (mbox/MH/maildir) and
and message / MIME parsing.

%package -n libetpan%{sover}
Summary:        Mail handling library
Group:          System/Libraries
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}

%description -n libetpan%{sover}
libEtPan is a mail purpose library. It will be used for low-level mail
handling: network protocols (IMAP/NNTP/POP3/SMTP over TCP/IP and
SSL/TCP/IP, already implemented), local storage (mbox/MH/maildir)
and message / MIME parsing.

%package -n libetpan-devel
Summary:        Development files for libetpan, a mail handling library
Group:          Development/Libraries/C and C++
Requires:       cyrus-sasl-devel
Requires:       db-devel
Requires:       libetpan%{sover} = %{version}
Requires:       openssl-devel

%description -n libetpan-devel
libEtPan is a mail purpose library. It will be used for low-level mail
handling: network protocols (IMAP/NNTP/POP3/SMTP over TCP/IP and
SSL/TCP/IP, already implemented), local storage (mbox/MH/maildir)
and message / MIME parsing.

%prep
%setup -q

%build
touch README INSTALL COPYING
autoreconf -fi
%configure --disable-static
%make_build

%install
%make_install
# remove unneeded *.la files
rm %{buildroot}%{_libdir}/libetpan.la

%post   -n libetpan%{sover} -p /sbin/ldconfig
%postun -n libetpan%{sover} -p /sbin/ldconfig

%files -n libetpan%{sover}
%doc ChangeLog NEWS doc/README*
%{_libdir}/libetpan.so.%{sover}*

%files -n libetpan-devel
%doc doc/API* doc/DOCUMENTATION
%{_includedir}/libetpan/
%{_includedir}/libetpan.h
%{_libdir}/libetpan.so
%{_libdir}/pkgconfig/libetpan.pc

%changelog
* Sat Aug 15 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.9.4 (bsc#1174579, CVE-2020-15953):
  * Bugfixes on QUOTA
  * Varios warning fixes & build fixes
* Wed Sep 25 2019 markus.beth@web.de
- update to version 1.9.3
  * Added IMAP CLIENTID / SMTP CLIENTID support
  * Use Cyrus SASL 2.1.27
- update to version 1.9.2
  * Support of TLS SNI
  * LMDB for cache DB
  * Fixed build with recent versions of curl
* Fri Sep 21 2018 markus.beth@web.de
- update to version 1.9.1
  * Fixed some build issues for Visual Studio
  * Fixes for GnuTLS
  * Various bug fixes
- Remove libetpan-1.6-openssl11.patch, fixed upstream
* Fri Jan 12 2018 jengelh@inai.de
- Rename %%soname to %%sover to better reflect its use.
* Thu Dec 14 2017 jengelh@inai.de
- Update RPM groups. Fix linguistic errors in description.
* Thu Dec 14 2017 axel.braun@gmx.de
- update to version 1.8
  * LMTP support
  * workaround for QIP IMAP Server
  * compatibility with NDK 13
  * fixed crash (CVE-2017-8825)
  * Fixed so name for Linux
* Thu Dec  7 2017 markus.beth@web.de
- added libetpan-1.6-openssl11.patch: make autodetection of OpenSSL
  1.1 work fix compilation error with OpenSSL 1.1 (boo#1070912)
* Sat Feb  7 2015 p.drouand@gmail.com
- Update to version 1.6
  * Improved RFC822 and MIME parser
  * Implemented SEARCH using LITERAL+ for Gmail
  * Fixed SSL connections (don't force SSLv3)
* Fri Jul 11 2014 reddwarf@opensuse.org
- Update to 1.5
  * Gmail search features: X-GM-MSGID, X-GM-THRID, X-GM-RAW
  * Added POP stat
  * Various fixes for Windows
  * Fixed OpenSSL / GnuTLS implementation of retrieval of certificates
  * Fixed IMAP IDLE in case of COMPRESS-ed streams
  * Fixed base64 encoding
* Thu Sep  5 2013 reddwarf@opensuse.org
- Update to 1.2
  * No summarized changes available, look at ChangeLog file
- Remove libetpan-0.56-uninitialized.patch, fixed upstream
- Remove libetpan-configure.patch, fixed upstrem
- Increase soname number
- Update Url and Source tags
- Use autoreconf (add autotools BuildRequires)
- Remove libcurl-devel and libexpat-devel BuildRequires. Its use
  has been disabled upstream
- Remove misleading --with-gnutls=yes configure option
* Sat Apr 13 2013 schwab@suse.de
- libetpan-configure.patch: Correct configure checks for libcurl and
  libexpat to work with --as-needed
* Sun Mar 18 2012 reddwarf@opensuse.org
- update to 1.1
  * Not summarized changes, look at ChangeLog file.
* Mon Dec 19 2011 coolo@suse.de
- remove very old stuff from spec file
* Thu Sep 30 2010 rhafer@novell.com
- Check for libdb-4.8
* Wed Jun 17 2009 puzel@suse.cz
- update to 0.58
  * Improvements on SSL implementation.
  * Gnutls: Better fix (API-compatible with libgnutls13)
  * Gnutls: Use compatibility mode to avoid being unable to
  * connect to some servers. (see Claws Mail's bug #1930)
  * SSL: Rehandshake if server asks to.
* Mon Dec  8 2008 puzel@suse.cz
- fix rpmlint warnings: summary not capitalized
- update to 0.57
  - fixed issue with GnuTLS
* Mon Oct 13 2008 nadvornik@suse.cz
- fixed rpmlint errors - implicit decrarations and ldconfig
* Fri Sep 12 2008 anosek@suse.cz
- updated to version 0.56
  * bugfix release
- removed libtool from BuildRequires
* Wed Mar  5 2008 anosek@suse.cz
- updated to version 0.54
  - fixed regression on IMAP APPEND
  - cleanup
  - version fixes
  - IPv6 issue
  - gmail issues
* Tue Sep 11 2007 ro@suse.de
- drop useless requires for librsaref2
* Mon Aug 13 2007 bwalle@suse.de
- sort this changes file to fix build in BuildService
* Fri Aug  3 2007 anosek@suse.cz
- updated to version 0.51
  * bugfix release
- dropped obsoleted mailsmtp.patch
* Wed Jul 25 2007 anosek@suse.cz
- updated to version 0.50
  * feature enhancements:
  RSS/ATOM feed implemented
  switched to automake build system
  IMAP IDLE implemented
  fetching by Message-Id implemented
  * fixes:
  several build fixes for Windows
  documentation build fixed
- fixed compilation error (mailsmtp.patch)
* Mon Jul 23 2007 suse-tux@gmx.de
- fixed build on older suse versions (< 1030)
- renamed devel package to libetpan-devel (as suggested by
  darix)
* Mon Jul  2 2007 lrupp@suse.de
- rsaref => librsaref2
* Sun Jun 17 2007 ro@suse.de
- fix another typo in  specfile
* Fri Jun 15 2007 ro@suse.de
- fix specfile (consistently use libetpan-devel)
* Thu Jun 14 2007 suse-tux@gmx.de
- minor spec fix
* Fri Jun  8 2007 suse-tux@gmx.de
- update package to fit to the Shared Library Packaging
  Policy
- remove unused *.a and *.la files
* Tue Jan  9 2007 anosek@suse.cz
- updated to version 0.49
  * feature enhancements:
    stream cancellation
    better handling of ssl error
    improved imap cache
  * fixes:
    various bugfixes
* Thu Dec  7 2006 anosek@suse.cz
- updated to version 0.48
  * IMAP UIDPLUS support
  * Various fixes
- fixed compiler warning: uninitialized variable used
  (uninitialized.patch)
* Wed Oct 25 2006 anosek@suse.cz
- fixed compiler warning: variable used before set
  [#212522] (dbdriver.patch)
* Tue Oct 17 2006 anosek@suse.cz
- updated to version 0.47
  * feature enhancements:
    IPv6 Support
  * fixes:
    various leaks and crashes
    MIME decoding fix
    gnutls fix
    SASL fix
    AUTH parser fix
* Tue Sep 26 2006 anosek@suse.cz
- new package, version 0.46
- taken from BuildService
  (maintainer Marcus Hüwe <marcus@links2linux.de>)
